@@ -9,10 +9,19 @@ impl Store for CSVStorage {
 	async fn fetch_schema(&self, _table_name: &str) -> Result<Option<Schema>> {
 		Ok(self.schema.clone())
 	}
+	async fn scan_schemas(&self) -> Result<Vec<Schema>> {
+		Ok(self
+			.schema
+			.clone()
+			.map(|schema| vec![schema])
+			.unwrap_or_default())
+	}
 
 	async fn scan_data(&self, _table_name: &str) -> Result<RowIter> {
-		let mut reader = csv_reader(&self)?;
+		let mut reader = csv_reader(self)?;
 
+		#[allow(clippy::needless_collect)]
+		// Clippy doesn't understand the need. Needed because we have borrowed values within.
 		let keyed_rows: Vec<Result<(Value, Row)>> = reader
 			.records()
 			.enumerate()
